Pem class

Constructors

Pem()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

openSshFooter String
final
openSshHeader String
final

Static Methods

loadPrivateKeyFromOpenSSHPem(String pemFileContent, {String? password}) Uint8List
Loads a private key from a pemFileContent that has been encoded with the open ssh file format: