Ppk class

Constructors

Ppk()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decodePpkPrivateKey(List<int> encryptedPrivateKey, String password) Uint8List
This method takes a encryptedPrivateKey and decrypts it by useing the provided password.
loadPrivateKeyFromPpk(String? ppkFileContent, {String? password}) Uint8List
This helper method takes a ppkFileContent and its password and extracts the private key into a list.
ppkMacCheck(String? privateMac, PpkMacData macData, String? password) → void
This method performs the mac check against the privateMac to validate the files content. It is also capable of testing whether the password was wrong or not. The macData is data used to compute the mac and to compare it to the given privateMac