PpkMacData class

Constructors

PpkMacData()

Properties

algorithm ↔ String
getter/setter pair
comment ↔ String
getter/setter pair
encryption ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
privateKey ↔ Uint8List
getter/setter pair
publicKey ↔ Uint8List
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited