ScramKeyCacheBinding class final

Exact derivation inputs that bind a reusable SCRAM client/server key pair.

Constructors

ScramKeyCacheBinding({required String authId, required String salt, required String kdf, required int iterations, required int memory, AuthenticationStringEncoding stringEncoding = AuthenticationStringEncoding.utf8})
const

Properties

authId → String
final
fingerprint → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
iterations → int
final
kdf → String
final
memory → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salt → String
final
stringEncoding → AuthenticationStringEncoding
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited