ScramKeyDerivationRequest class final

Inputs for a single SCRAM password-key derivation.

Constructors

ScramKeyDerivationRequest({required Uint8List password, required Uint8List salt, required String kdf, required int iterations, required int memory, required int keyLength})

Properties

hashCode int
The hash code for this object.
no setterinherited
iterations int
final
kdf String
final
keyLength int
final
memory int
final
password Uint8List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salt Uint8List
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited