ScramKeyDeriver class abstract interface

Runs expensive SCRAM key derivation away from the caller's event loop.

Constructors

ScramKeyDeriver()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start(ScramKeyDerivationRequest request, {Duration? timeout}) → ScramKeyDerivationTask
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited