TicketAuthentication class

Ticket-based authentication implementation shared by client and router.

Inheritance

Constructors

TicketAuthentication(String password)

Properties

hashCode → int
The hash code for this object.
no setterinherited
onChallenge → Stream<Extra>
When the challenge starts the stream will provide the current Extra in case the client needs some additional information to challenge the server.
no setteroverride
password ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelPendingChallenge() → Future<void>
Cancels work associated with the current authentication attempt.
inherited
challenge(Extra extra) → Future<Authenticate>
Called when the router sends a challenge (CHALLENGE frame).
override
dispose() → Future<void>
Releases authentication-method resources.
inherited
getName() → String
Authentication method name used in HELLO (e.g. 'ticket').
override
hello(String? realm, Details details) → Future<void>
This method is called to modify the hello details for a given realm.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
verifyFinal({required String? authId, required String? authMethod, required Map<String, Object?>? authExtra}) → Future<void>
Verifies authentication data returned by the router before session use.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

verify({required String expectedTicket, required String providedSignature}) → bool