hasDecodedPptPayload property
bool
get
hasDecodedPptPayload
Whether the current argument view has already removed a PPT wrapper.
Implementation
bool get hasDecodedPptPayload => _pptPayloadDecoded;
Whether the current argument view has already removed a PPT wrapper.
bool get hasDecodedPptPayload => _pptPayloadDecoded;