hasLazyArguments property
bool
get
hasLazyArguments
Whether encoded positional arguments are waiting to be decoded.
Implementation
bool get hasLazyArguments => _encodedArguments != null;
Whether encoded positional arguments are waiting to be decoded.
bool get hasLazyArguments => _encodedArguments != null;