markPptPayloadDecoded method
void
markPptPayloadDecoded()
Marks the current argument view as already unwrapped from PPT.
Implementation
void markPptPayloadDecoded() {
_pptPayloadDecoded = true;
}
Marks the current argument view as already unwrapped from PPT.
void markPptPayloadDecoded() {
_pptPayloadDecoded = true;
}