AbstractSerializer class abstract

The custom serializer interface

Constructors

AbstractSerializer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deserialize(Uint8List? message) AbstractMessage?
Deserialize a given message
deserializePPT(Uint8List binPayload) PPTPayload?
Deserialize and prepare payload from PPT Mode
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(AbstractMessage message) → dynamic
Serialize a given message, should return a String or a UInt8List. The return type is dynamic, because the socket class takes a dynamic type to send either a string or a binary message.
serializeFragments(AbstractMessage message) List<Uint8List>?
Returns encoded message fragments when the serializer can preserve an already-encoded payload without assembling one contiguous frame.
serializePPT(PPTPayload pptPayload) Uint8List
Serializer Payload for PPT Mode
serializePPTFragments({Uint8List? argumentsBytes, Uint8List? argumentsKeywordsBytes, List? arguments, Map<String, dynamic>? argumentsKeywords}) Uint8List
Serializer PPT payload from already-encoded args / kwargs fragments when the payload serializer matches the surrounding transport serializer.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited