AbstractTransport class abstract

Implementers

Constructors

AbstractTransport()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isOpen → bool
no setter
isReady → bool
no setter
onConnectionLost → Completer?
no setter
onDisconnect → Completer?
no setter
onReady → Future<void>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close({dynamic error}) → Future<void>?
complete(Completer? onDisconnectCompleter, dynamic error) → void
for internal use only is called to complete the private underlying onDisconnect with a void or an error
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open({Duration? pingInterval}) → Future<void>?
receive() → Stream<AbstractMessage?>?
send(AbstractMessage message) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited