Authenticate class

The WAMP Authenticate massage

Inheritance

Constructors

Authenticate({String? signature})
Creates a WAMP Authentication message with a signature that was cryptographically created by an authentication method of this package
Authenticate.signature(String signature)
A factory that creates an instance of a WAMP Authenticate massage by passing in a signature that was cryptographically created by an authentication method of this package
factory

Properties

extra Map<String, Object?>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited