Authenticate constructor

Authenticate({
  1. String? signature,
})

Creates a WAMP Authentication message with a signature that was cryptographically created by an authentication method of this package

Implementation

Authenticate({this.signature}) {
  id = MessageTypes.codeAuthenticate;
}