Call constructor
Call(})
Creates a WAMP Call message with a requestId that is kind of like a
transaction identifier and a procedure that was registered to the router
before. The options field may be passed to configure the call
Implementation
Call(
this.requestId,
this.procedure, {
this.options,
List<dynamic>? arguments,
Map<String, dynamic>? argumentsKeywords,
}) {
id = MessageTypes.codeCall;
this.arguments = arguments;
this.argumentsKeywords = argumentsKeywords;
}