CallOptions class
Options used influence the call behavior
- Inheritance
-
- Object
- PPTOptions
- CallOptions
- Mixed-in types
Constructors
Properties
-
custom
→ Map<
String, dynamic> -
Arbitrary implementation-specific fields that should be forwarded over
the wire when serializing WAMP options/details.
finalinherited
- discloseMe ↔ bool?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- pptCipher ↔ String?
-
getter/setter pairinherited
- pptKeyId ↔ String?
-
getter/setter pairinherited
- pptScheme ↔ String?
-
getter/setter pairinherited
- pptSerializer ↔ String?
-
getter/setter pairinherited
- progress ↔ bool?
-
getter/setter pair
- receiveProgress ↔ bool?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout ↔ int?
-
getter/setter pair
- transactionHash ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeCustomField(
String key) → void -
Removes a previously assigned custom field.
inherited
-
setCustomField(
String key, dynamic value) → void -
Assigns
valueto the custom fieldkey. Existing values are replaced.inherited -
setLazyCustomFieldsLoader(
Map< String, dynamic> loader()) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
verify(
) → bool -
override
-
verifyPPT(
) → bool -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- maxTransactionHashBytes → const int
- transactionHashWireField → const String