Challenge class

The WAMP Challenge massage

Inheritance

Constructors

Challenge(String authMethod, Extra extra)
Creates a WAMP Challenge message that is returned by the router to challenge the client with a given authMethod and some extra authentication data

Properties

authMethod ↔ String
getter/setter pair
extra ↔ Extra
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited