Client class
Constructors
-
Client({required AbstractTransport transport, String? authId, String? authRole, String? realm, List<
AbstractAuthentication> ? authenticationMethods, Map<String, dynamic> ? authExtra, WampE2eeProvider? e2eeProvider, SessionE2eeProviderResolver? e2eeProviderResolver, int isolateCount = 1}) -
The client connects to the wamp server by using the given
transportand the givenauthenticationMethods. Passing more then one AbstractAuthentication to the client will make the router choose which method to choose. TheauthIdand therealmwill be used for all givenauthenticationMethods
Properties
-
authenticationMethods
↔ List<
AbstractAuthentication> ? -
getter/setter pair
-
authExtra
↔ Map<
String, dynamic> ? -
getter/setter pair
- authId ↔ String?
-
getter/setter pair
- authRole ↔ String?
-
getter/setter pair
- e2eeProvider → WampE2eeProvider?
-
final
- e2eeProviderResolver → SessionE2eeProviderResolver?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isolateCount ↔ int
-
getter/setter pair
-
onNextTryToReconnect
→ Stream<
ClientConnectOptions> -
if listened to this stream you will be noticed about reconnect tries. The passed
integer will be the current retry counted down from where you started in the configured
ClientConnectOptions.reconnectCount passed to the connect method. Be aware a zero is passed just
before the connect streams
onErrorwill raise the abort message. So 0 means that the reconnect failed.no setter - realm ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transport → AbstractTransport
-
final
Methods
-
connect(
{ClientConnectOptions? options}) → Stream< Session> - Calling this method will start the authentication process and result into a Session object on success. If a ClientConnectOptions.pingInterval is given and the underlying transport supports sending of ping messages. the given duration is used by the transport to send ping messages every ClientConnectOptions.pingInterval. SocketTransport and WebSocketTransport not within the browser support ping messages. The browser API does not allow to control ping messages. If ClientConnectOptions.reconnectCount and the ClientConnectOptions.reconnectTime is set the client will try to reestablish the session. Setting ClientConnectOptions.reconnectCount to -1 will infinite times reconnect the client or until the stack overflows
-
disconnect(
) → Future< void> - Close connection.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited