onNextTryToReconnect property
Stream<ClientConnectOptions>
get
onNextTryToReconnect
if listened to this stream you will be noticed about reconnect tries. The passed
integer will be the current retry counted down from where you started in the configured
ClientConnectOptions.reconnectCount passed to the connect method. Be aware a zero is passed just
before the connect streams onError will raise the abort message. So 0 means
that the reconnect failed.
Implementation
Stream<ClientConnectOptions> get onNextTryToReconnect =>
_connectStreamController.stream;