ClientConnectOptions class

Constructors

ClientConnectOptions({int reconnectCount = 3, Duration? reconnectTime, Duration? pingInterval})

Properties

hashCode → int
The hash code for this object.
no setterinherited
pingInterval ↔ Duration?
getter/setter pair
reconnectCount ↔ int
getter/setter pair
reconnectTime ↔ Duration?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

minusReconnectRetry() → ClientConnectOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited