CustomFieldContainer mixin

Provides storage for implementation-specific fields on WAMP option/detail objects. Keys follow the WAMP convention of starting with an underscore, but this container does not enforce validation so callers can remain interoperable with peers that use legacy key formats.

Properties

custom Map<String, dynamic>
Arbitrary implementation-specific fields that should be forwarded over the wire when serializing WAMP options/details.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeCustomField(String key) → void
Removes a previously assigned custom field.
setCustomField(String key, dynamic value) → void
Assigns value to the custom field key. Existing values are replaced.
setLazyCustomFieldsLoader(Map<String, dynamic> loader()) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited