DealerFeatures class

Constructors

DealerFeatures()

Properties

callCanceling ↔ bool
getter/setter pair
callerIdentification ↔ bool
getter/setter pair
callTimeout ↔ bool
getter/setter pair
callTrustLevels ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
patternBasedRegistration ↔ bool
getter/setter pair
payloadPassThruMode ↔ bool
getter/setter pair
progressiveCallInvocations ↔ bool
getter/setter pair
progressiveCallResults ↔ bool
getter/setter pair
registrationMetaApi ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionMetaApi ↔ bool
getter/setter pair
sharedRegistration ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited