Extra class

Challenge values to check the authentication validity

Mixed-in types

Constructors

Extra({String? challenge, String? salt, int? keyLen, String? channelBinding, int? iterations, int? memory, String? kdf, String? nonce, Map<String, dynamic>? custom})
Extra.fromMap(Map<String, dynamic> map)
factory

Properties

challenge ↔ String?
getter/setter pair
channelBinding ↔ String?
getter/setter pair
custom → Map<String, dynamic>
Arbitrary implementation-specific fields that should be forwarded over the wire when serializing WAMP options/details.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
iterations ↔ int?
getter/setter pair
kdf ↔ String?
getter/setter pair
keyLen ↔ int?
getter/setter pair
memory ↔ int?
getter/setter pair
nonce ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salt ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeCustomField(String key) → void
Removes a previously assigned custom field.
inherited
setCustomField(String key, dynamic value) → void
Assigns value to the custom field key. Existing values are replaced.
inherited
setLazyCustomFieldsLoader(Map<String, dynamic> loader()) → void
inherited
setLazyLoader(Map<String, dynamic> loader()) → void
toMap() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited