FileSegmentTransport class abstract interface

Optional transport capability for file-backed WAMP message payloads.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportsFileSegments bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openFileSegmentSource(String path, int expectedLength) TransportFileSource
sendFileSegment(AbstractMessage message, {required TransportFileSource source, required int offset, required int length}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited