PPTOptions class abstract

Payload PassThru Options are the same across all wamp messages this provides a common checks for them

Constructors

PPTOptions()

Properties

hashCode int
The hash code for this object.
no setterinherited
pptCipher String?
getter/setter pair
pptKeyId String?
getter/setter pair
pptScheme String?
getter/setter pair
pptSerializer String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verify() bool
verifyPPT() bool

Operators

operator ==(Object other) bool
The equality operator.
inherited