ProgressiveCall class

Properties

hashCode → int
The hash code for this object.
no setterinherited
isFinished → bool
no setter
requestId → int
final
results → Stream<Result>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsFileSegments → bool
no setter

Methods

drain() → Future<void>
Gives a capable transport a local write-pacing opportunity.
finish({List? arguments, Map<String, dynamic>? argumentsKeywords}) → void
finishFileSegment(TransportFileSource source, {required int offset, required int length}) → void
finishLazy(LazyMessagePayload payload) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openFileSource(String path, int expectedLength) → TransportFileSource
sendChunk({List? arguments, Map<String, dynamic>? argumentsKeywords}) → void
sendFileSegment(TransportFileSource source, {required int offset, required int length}) → void
sendLazyChunk(LazyMessagePayload payload) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited