drain method
Gives a capable transport a local write-pacing opportunity.
Completion is not an acknowledgement from the remote peer.
Implementation
Future<void> drain() => _drain?.call() ?? Future<void>.value();
Gives a capable transport a local write-pacing opportunity.
Completion is not an acknowledgement from the remote peer.
Future<void> drain() => _drain?.call() ?? Future<void>.value();