authenticate method
This sends the authenticate message to the transport outgoing stream.
Implementation
void authenticate(Authenticate authenticate) {
_transport.send(authenticate);
}
This sends the authenticate message to the transport outgoing stream.
void authenticate(Authenticate authenticate) {
_transport.send(authenticate);
}