register method
This registers a procedure with the given options that may be called
by other sessions.
Implementation
Future<Registered> register(String procedure, {RegisterOptions? options}) {
return _register(procedure, options: options);
}
This registers a procedure with the given options that may be called
by other sessions.
Future<Registered> register(String procedure, {RegisterOptions? options}) {
return _register(procedure, options: options);
}