SocketTransport constructor

SocketTransport(
  1. String host,
  2. int port,
  3. AbstractSerializer serializer,
  4. String serializerType, {
  5. dynamic ssl = false,
  6. dynamic allowInsecureCertificates = false,
  7. Object? tlsSecurityContext,
  8. dynamic messageLengthExponent = SocketHelper.maxMessageLengthExponent,
})

This creates a socket transport instance. The messageLengthExponent configures the max message length that will be excepted to be send and received. It is negotiated with the router and may lead into a lower value that messageLengthExponent if the router only supports shorter messages. The message length is calculated by 2^messageLengthExponent

Implementation

SocketTransport(
  String host,
  int port,
  AbstractSerializer serializer,
  String serializerType, {
  ssl = false,
  allowInsecureCertificates = false,
  Object? tlsSecurityContext,
  messageLengthExponent = SocketHelper.maxMessageLengthExponent,
});