sendPing method

Future<Uint8List?> sendPing({
  1. Duration? timeout,
})

Send a ping message to keep the connection alive. The returning future will fail if no pong is received withing the given timeout. The default timeout is 5 seconds.

Implementation

Future<Uint8List?> sendPing({Duration? timeout}) async => Future.value();