Subscribe class

Used to subscribe to a topic

Inheritance

Constructors

Subscribe(int requestId, String topic, {SubscribeOptions? options})
The requestId will identify the subscription server response. The topic is the actual topic to subscribe to or a prefix or wildcard topic as defined in the options.

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pairinherited
options ↔ SubscribeOptions?
getter/setter pair
requestId ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topic ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited