setCustomField method
Sets a custom option that will be serialized using json.encode for the
JSON serializer and passed through unchanged for binary serializers.
Implementation
@override
void setCustomField(String key, dynamic value) {
custom[key] = value;
}