Subscribed class

Is returned by the subscription process

Inheritance

Constructors

Subscribed(int subscribeRequestId, int subscriptionId)
the constructor with a subscribeRequestId initially sent to the server and a subscriptionId that was generated by the server

Properties

eventStream Stream<Event>?
Is created by the protocol processor and will receive an event object when the transport receives one
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasLazyPayloadEventHandler bool
no setter
hasMaterializedEventConsumers bool
no setter
hasPayloadEventHandler bool
no setter
id int
getter/setter pairinherited
onRevoke Future<String>
Is completed when the revocation happens
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscribeRequestId int
getter/setter pair
subscriptionId int
getter/setter pair
topic String?
getter/setter pair

Methods

addEvent(Event event) → void
addEventPayload(EventPayload event) → void
addLazyEventPayload(LazyEventPayload event) → void
closeEventStream() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onEvent(void onEvent(Event event)) → void
onEventPayload(void onEvent(EventPayload event)) → void
onLazyEventPayload(void onEvent(LazyEventPayload event)) → void
revoke(String? reason) → void
Is called by the session when the revocation happens
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited