eventStream property
Is created by the protocol processor and will receive an event object when the transport receives one
Implementation
Stream<Event>? get eventStream {
return _eventStreamOverride ??
(_eventController ??= _newEventController()).stream;
}