SubscriberFeatures class

Constructors

SubscriberFeatures()

Properties

callCanceling ↔ bool
getter/setter pair
callTimeout ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
patternBasedSubscription ↔ bool
getter/setter pair
payloadPassThruMode ↔ bool
getter/setter pair
progressiveCallResults ↔ bool
getter/setter pair
publicationTrustLevels ↔ bool
getter/setter pair
publisherIdentification ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriptionRevocation ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited