UriPattern class

Constructors

UriPattern()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

regularPattern Pattern
final
wildcardPattern Pattern
final

Static Methods

match(String uri) bool
Test if a given uri matches a regular uri pattern
matchWildcard(String uri) bool
Test if a given uri matches a regular wildcard uri