WampFileReceipt class

Immutable completion information supplied to WampFileSink.close.

Constructors

WampFileReceipt({required WampFileMetadata metadata, required int receivedBytes, required String sha256Digest})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
metadata WampFileMetadata
final
receivedBytes int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sha256Digest String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited