WampFileSink class abstract

Backpressure-aware destination for incoming file chunks.

Constructors

WampFileSink()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

abort(Object error) FutureOr<void>
May run concurrently with an in-flight add to unblock failed transfers.
add(Uint8List chunk) FutureOr<void>
close(WampFileReceipt receipt) FutureOr<Map<String, dynamic>?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited