WampFileSource class

Re-openable byte source used by WampFileSession.setFile.

Constructors

WampFileSource({required String name, required int length, required Stream<Uint8List> openRead(), Stream<Uint8List> openReadChunks(int chunkSize)?, String? contentType, String? sha256Digest, String? nativePath, Map<String, dynamic>? custom})
WampFileSource.bytes(Uint8List bytes, {required String name, String? contentType, String? sha256Digest, Map<String, dynamic>? custom})
factory

Properties

contentType → String?
final
custom → Map<String, dynamic>
final
hashCode → int
The hash code for this object.
no setterinherited
length → int
final
name → String
final
nativePath → String?
final
openRead → Stream<Uint8List> Function()
final
openReadChunks → Stream<Uint8List> Function(int chunkSize)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sha256Digest → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited