close method
Releases the lifecycle subscriptions and closes the change stream.
Implementation
Future<void> close() => _dispose(releaseSubscriptions: true);
Releases the lifecycle subscriptions and closes the change stream.
Future<void> close() => _dispose(releaseSubscriptions: true);