WampRegistrationMeta class final

Standard registration details plus the current callee session IDs.

Constructors

WampRegistrationMeta.fromDetails(int id, Map<String, dynamic> details, {Iterable<int> callees = const <int>[]})

Properties

callees Set<int>
final
details Map<String, Object?>
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
invoke String?
no setter
match String?
no setter
procedure String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({required Iterable<int> callees}) WampRegistrationMeta
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited