WampSessionMeta class final

Standard wamp.session.get details retained by the cache.

Constructors

WampSessionMeta.fromDetails(int id, Map<String, dynamic> details)

Properties

authId String?
no setter
authMethod String?
no setter
authProvider String?
no setter
authRole String?
no setter
details Map<String, Object?>
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited