WampSubscriptionMeta class final

Standard subscription details plus the current subscriber session IDs.

Constructors

WampSubscriptionMeta.fromDetails(int id, Map<String, dynamic> details, {Iterable<int> subscribers = const <int>[]})

Properties

details Map<String, Object?>
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
match String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscribers Set<int>
final
topic String?
no setter

Methods

copyWith({required Iterable<int> subscribers}) WampSubscriptionMeta
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited