Welcome class

Is passed if a session was created by the server after or without an authentication process

Inheritance

Constructors

Welcome(int sessionId, Details details)
the constructor with a server generated sessionId and other details

Properties

details Details
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited