FlatBufferByteVectorReference class

Reuse a byte vector already constructed in this builder's storage. This reference never adopts external pointers or another allocation. Consume it during the same build, before resetting the builder.

Constructors

FlatBufferByteVectorReference(Builder builder, int offset)

Properties

builder → Builder
final
hashCode → int
The hash code for this object.
no setterinherited
offset → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited