ConnectanumHttpAuthException class final
- Implemented types
Constructors
- ConnectanumHttpAuthException({required int statusCode, required String reasonPhrase, required String body, Object? error})
-
const
Properties
- body → String
-
final
- error → Object?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- reasonPhrase → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited