McpCompletionRequest class final

A typed completion/complete request body.

Constructors

McpCompletionRequest({required McpCompletionReference reference, required McpCompletionArgument argument, McpCompletionContext? context})
McpCompletionRequest.fromJson(Map<Object?, Object?> json)
factory

Properties

argument → McpCompletionArgument
final
context → McpCompletionContext?
final
hashCode → int
The hash code for this object.
no setterinherited
reference → McpCompletionReference
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited