McpFormElicitationRequest class final

One validated form-mode elicitation/create input request.

Constructors

McpFormElicitationRequest({required String inputRequestId, required String message, required McpJsonMap requestedSchema})
factory
McpFormElicitationRequest.fromJson(String inputRequestId, Object? value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
inputRequestId String
final
message String
final
requestedSchema McpJsonMap
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited