McpFormElicitationResponse class final
A consumer's response to one MCP form elicitation request.
Constructors
- McpFormElicitationResponse.accept(McpJsonMap content)
-
factory
- McpFormElicitationResponse.cancel()
-
const
- McpFormElicitationResponse.decline()
-
const
Properties
- action → McpElicitationAction
-
final
- content → McpJsonMap?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonFor(
McpFormElicitationRequest request) → McpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited