McpOAuthClientAuthentication class final

Client authentication used at an OAuth token endpoint.

Constructors

McpOAuthClientAuthentication.clientSecretBasic({required String clientId, required String clientSecret, required McpAuthorizationServerMetadata authorizationServer})
factory
McpOAuthClientAuthentication.clientSecretPost({required String clientId, required String clientSecret, required McpAuthorizationServerMetadata authorizationServer})
factory
McpOAuthClientAuthentication.none(String clientId)
Creates portable public-client authentication for an HTTPS Client ID Metadata Document.
factory
McpOAuthClientAuthentication.registeredPublic({required String clientId, required McpAuthorizationServerMetadata authorizationServer})
Creates public-client authentication bound to one validated issuer.
factory

Properties

authorizationServerIssuer String?
Exact validated issuer for registered credentials, or null only for a portable HTTPS Client ID Metadata Document identity.
final
clientId String
final
hashCode int
The hash code for this object.
no setterinherited
method String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited