authorizationServerIssuer property
Exact validated issuer for registered credentials, or null only for a
portable HTTPS Client ID Metadata Document identity.
Implementation
final String? authorizationServerIssuer;
Exact validated issuer for registered credentials, or null only for a
portable HTTPS Client ID Metadata Document identity.
final String? authorizationServerIssuer;