McpOAuthClientMetadataDocument class final

Constructors

McpOAuthClientMetadataDocument.publicClient({required Uri clientId, required String clientName, required Iterable<Uri> redirectUris, Uri? clientUri, Uri? logoUri, Iterable<String> scopes = const <String>[], bool requestRefreshTokens = true})
factory

Properties

clientAuthentication McpOAuthClientAuthentication
no setter
clientId Uri
final
clientName String
final
clientUri Uri?
final
hashCode int
The hash code for this object.
no setterinherited
logoUri Uri?
final
redirectUris List<Uri>
final
requestsRefreshTokens bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>
final

Methods

createAuthorizationRequest({required McpAuthorizationServerMetadata authorizationServer, required Uri resource, required Uri redirectUri, Iterable<String>? scopes, McpPkcePair? pkce}) McpAuthorizationRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited