McpOAuthClientRegistrationException class final

Implemented types

Constructors

McpOAuthClientRegistrationException(String message, {Uri? endpoint, int? statusCode, String? registrationError, String? errorDescription})
const

Properties

endpoint Uri?
final
errorDescription String?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
registrationError String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited