McpOAuthDynamicClientRegistrationRequest class final

Constructors

McpOAuthDynamicClientRegistrationRequest.publicClient({required String clientName, required Iterable<Uri> redirectUris, required McpOAuthClientApplicationType applicationType, Uri? clientUri, Uri? logoUri, Iterable<String> scopes = const <String>[]})
factory

Properties

applicationType McpOAuthClientApplicationType
final
clientName String
final
clientUri Uri?
final
hashCode int
The hash code for this object.
no setterinherited
logoUri Uri?
final
redirectUris List<Uri>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited