McpOAuthExternalUserAgentLauncher typedef
Opens a prepared OAuth authorization URI in an external user-agent.
Implementations should return after the platform has accepted the launch request. They may complete later, because the loopback listener consumes the authorization response concurrently.
Implementation
typedef McpOAuthExternalUserAgentLauncher =
FutureOr<void> Function(Uri authorizationUri);