McpOAuthLoopbackCallbackException class final

A redacted failure from the native OAuth loopback callback listener.

Implemented types

Constructors

McpOAuthLoopbackCallbackException(String message, {Uri? redirectUri})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
redirectUri Uri?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited