McpOAuthLoopbackCallbackListener class final

Receives one native OAuth authorization response on a loopback IP literal.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isClosed → bool
Whether this listener has released its bound socket.
no setter
redirectUri → Uri
The exact redirect URI to register and use for the authorization request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

authorizeWithExternalUserAgent({required McpAuthorizationRequest request, required McpOAuthExternalUserAgentLauncher launchExternalUserAgent, Duration timeout = _defaultCallbackTimeout, int maxRequests = _defaultMaxRequests}) → Future<McpAuthorizationCode>
Opens request in an external user-agent and awaits its callback.
close() → Future<void>
Releases the bound socket. Calling this more than once is safe.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
waitForAuthorizationCode({required McpAuthorizationRequest request, Duration timeout = _defaultCallbackTimeout, int maxRequests = _defaultMaxRequests}) → Future<McpAuthorizationCode>
Waits once for the authorization response that matches request.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

bind({InternetAddress? address, int port = 0, String path = _defaultCallbackPath}) → Future<McpOAuthLoopbackCallbackListener>
Binds an RFC 8252 loopback redirect listener.