McpOAuthTokenException class final

A local token-flow failure or typed OAuth token endpoint error.

Implemented types

Constructors

McpOAuthTokenException(String message, {Uri? endpoint, int? statusCode, String? oauthError, String? errorDescription, Uri? errorUri})
const

Properties

endpoint Uri?
final
errorDescription String?
final
errorUri Uri?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
oauthError String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited