McpProtectedResourceDiscovery class final

The result of Protected Resource Metadata discovery.

Constructors

McpProtectedResourceDiscovery({required Uri metadataUri, required McpProtectedResourceMetadata metadata, required McpBearerChallenge? challenge})
const

Properties

challenge McpBearerChallenge?
final
hashCode int
The hash code for this object.
no setterinherited
metadata McpProtectedResourceMetadata
final
metadataUri Uri
final
requiredScopes List<String>
Scopes required for the current request, honoring the MCP priority order.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited