McpStreamableHttpException class final

Implemented types

Constructors

McpStreamableHttpException({required int statusCode, required String reasonPhrase, required String body, McpJsonMap? error, Map<String, List<String>> responseHeaders = const <String, List<String>>{}, List<McpBearerChallenge> bearerChallenges = const <McpBearerChallenge>[]})
const

Properties

bearerChallenges → List<McpBearerChallenge>
final
body → String
final
error → McpJsonMap?
final
hashCode → int
The hash code for this object.
no setterinherited
reasonPhrase → String
final
responseHeaders → Map<String, List<String>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited