McpStreamableToolListPage class final
Constructors
-
McpStreamableToolListPage({required List<
McpJsonMap> tools, String? nextCursor}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextCursor → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tools
→ List<
McpJsonMap> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited