McpStreamableWampMetaCallResult class final

Constructors

McpStreamableWampMetaCallResult({required String procedure, required List<Object?> arguments, required McpJsonMap argumentsKeywords, required McpJsonMap structuredContent})
const
McpStreamableWampMetaCallResult.fromJson(String procedure, McpJsonMap structuredContent)
factory

Properties

arguments → List<Object?>
final
argumentsKeywords → McpJsonMap
final
hashCode → int
The hash code for this object.
no setterinherited
procedure → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
structuredContent → McpJsonMap
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited