McpStreamableWampSubscriptionResult class final

Constructors

McpStreamableWampSubscriptionResult({required String handle, required String topic, required int queueLimit, int? queueByteLimit, int? subscriptionId, required McpJsonMap structuredContent})
const
McpStreamableWampSubscriptionResult.fromJson(McpJsonMap structuredContent)
factory

Properties

handle String
final
hashCode int
The hash code for this object.
no setterinherited
queueByteLimit int?
final
queueLimit int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structuredContent McpJsonMap
final
subscriptionId int?
final
topic String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited