NativeBufferBuilder class final

Writes initialized native memory without exposing mutable typed-data views.

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
length → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
freeze({int offset = 0, int? length}) → NativeOwnedBuffer
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setUint32(int offset, int value, [Endian endian = Endian.little]) → void
setUint64(int offset, int value, [Endian endian = Endian.little]) → void
setUint8(int offset, int value) → void
toString() → String
A string representation of this object.
inherited
writeBytes(int offset, List<int> bytes) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited