NativeBufferToken class final
Native integration output from ct_external_buffer_register.
Publish this initialized structure to exactly one Dart consumer. Its handle
is a resource reference; copying/forging the fields does not retain it.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - handle ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
identity
↔ Pointer<
Void> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited