putInt64 method

  1. @override
void putInt64(
  1. int value
)
override

Writes a Int64 to the tail of the buffer after preparing space for it.

Updates the offset pointer. This method is intended for use when writing structs to the buffer.

Implementation

@override
void putInt64(int value) => _write(() => _builder.putInt64(value));