putInt8 method

  1. @override
void putInt8(
  1. int value
)
override

Writes a Uint8 to the tail of the buffer after preparing space for it.

Updates the offset pointer. This method is intended for use when writing structs to the buffer.

Implementation

@override
void putInt8(int value) => _write(() => _builder.putInt8(value));