native_message_bytes library

Shared VM-only native message storage support for the client and router.

Classes

NativeMessageBytes
Creates byte views that remain valid after a routing handle is released.

Enums

NativeMessageBytePart
Stable native slice selectors; these values are part of the FFI ABI.