messageHandleAbi property
The same complete ABI used by the client and router message bindings.
Implementation
final NativeMessageHandleAbi messageHandleAbi;
The same complete ABI used by the client and router message bindings.
final NativeMessageHandleAbi messageHandleAbi;