supportsZeroCopy property
bool
get
supportsZeroCopy
Whether this runtime can retain message bytes without a payload copy.
Implementation
bool get supportsZeroCopy => _export != null;
Whether this runtime can retain message bytes without a payload copy.
bool get supportsZeroCopy => _export != null;