AbstractAuthentication class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onChallenge
→ Stream<
Extra> -
When the challenge starts the stream will provide the current Extra in
case the client needs some additional information to challenge the server.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelPendingChallenge(
) → Future< void> - Cancels work associated with the current authentication attempt.
-
challenge(
Extra extra) → Future< Authenticate> - Called when the router sends a challenge (CHALLENGE frame).
-
dispose(
) → Future< void> - Releases authentication-method resources.
-
getName(
) → String - Authentication method name used in HELLO (e.g. 'ticket').
-
hello(
String? realm, Details details) → Future< void> -
This method is called to modify the hello
detailsfor a givenrealm. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
verifyFinal(
{required String? authId, required String? authMethod, required Map< String, Object?> ? authExtra}) → Future<void> - Verifies authentication data returned by the router before session use.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
streamAddAwaited<
T> (StreamController< T> streamController, T value, {bool predicate(T event)?, Duration? timeout}) → Future<T>