Pkcs8 class
Constructors
- Pkcs8()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromEd25519Seed(
Uint8List seed) → String - Creates a not encrypted PKCS#8 file from a 32-Byte-Ed25519-Seed.
-
loadPrivateKeyFromPKCS8Ed25519(
String pem) → Uint8List - Reads a not encrypted PKCS#8 file and returns a 32-Byte-Ed25519-Seed.