Authenticate class
The WAMP Authenticate massage
- Inheritance
-
- Object
- AbstractMessage
- Authenticate
Constructors
- Authenticate({String? signature})
-
Creates a WAMP Authentication message with a
signaturethat was cryptographically created by an authentication method of this package - Authenticate.signature(String signature)
-
A factory that creates an instance of a WAMP Authenticate massage by
passing in a
signaturethat was cryptographically created by an authentication method of this packagefactory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited