BrokerFeatures class

Broker feature flags advertised in WAMP WELCOME.Details.

Constructors

BrokerFeatures()

Properties

eventHistory bool
Whether the broker supports event-history retrieval.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
patternBasedSubscription bool
Whether the broker supports prefix and wildcard subscriptions.
getter/setter pair
payloadPassThruMode bool
Whether the broker supports WAMP Payload Passthru Mode.
getter/setter pair
publicationTrustLevels bool
Whether events may include a router-assigned publication trust level.
getter/setter pair
publisherExclusion bool
Whether publishers may control delivery to their own session.
getter/setter pair
publisherIdentification bool
Whether events may disclose the publisher session ID.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionMetaApi bool
Whether the broker exposes the WAMP session meta API.
getter/setter pair
subscriberBlackWhiteListing bool
Whether publishers may include or exclude specific subscribers.
getter/setter pair
subscriptionMetaApi bool
Whether the broker exposes the WAMP subscription meta API.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited