InvocationDetails class

Inheritance
Mixed-in types

Constructors

InvocationDetails(int? caller, String? procedure, bool? receiveProgress, [String? pptScheme, String? pptSerializer, String? pptCipher, String? pptKeyId, Map<String, dynamic>? custom])

Properties

caller int?
getter/setter pair
custom Map<String, dynamic>
Arbitrary implementation-specific fields that should be forwarded over the wire when serializing WAMP options/details.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
pptCipher String?
getter/setter pairinherited
pptKeyId String?
getter/setter pairinherited
pptScheme String?
getter/setter pairinherited
pptSerializer String?
getter/setter pairinherited
procedure String?
getter/setter pair
progress bool?
getter/setter pair
receiveProgress bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeCustomField(String key) → void
Removes a previously assigned custom field.
inherited
setCustomField(String key, dynamic value) → void
Assigns value to the custom field key. Existing values are replaced.
inherited
setLazyCustomFieldsLoader(Map<String, dynamic> loader()) → void
inherited
toString() String
A string representation of this object.
inherited
verify() bool
override
verifyPPT() bool
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited