LazyEventPayload class
Constructors
Properties
- arguments → List?
-
no setter
- argumentsBytes → Uint8List?
-
no setter
-
argumentsKeywords
→ Map<
String, dynamic> ? -
no setter
- argumentsKeywordsBytes → Uint8List?
-
no setter
-
customDetails
→ Map<
String, dynamic> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- packedPayloadBytes → Uint8List?
-
no setter
- payload → LazyMessagePayload
-
final
- pptCipher → String?
-
final
- pptKeyId → String?
-
final
- pptScheme → String?
-
final
- pptSerializer → String?
-
final
- publicationId → int
-
final
- publisher → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriptionId → int
-
final
- topic → String?
-
final
- trustlevel → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toPayload(
) → EventPayload -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited