LazyInvocationPayload class

Constructors

LazyInvocationPayload({required int requestId, required int registrationId, required bool receiveProgress, required InvocationPayloadResponder respondWith, required bool isResponseClosed(), required LazyMessagePayload payload, bool progress = false, int? timeout, int? caller, String? procedure, String? pptScheme, String? pptSerializer, String? pptCipher, String? pptKeyId, Map<String, dynamic>? customDetails})

Properties

arguments List?
no setter
argumentsBytes Uint8List?
no setter
argumentsKeywords Map<String, dynamic>?
no setter
argumentsKeywordsBytes Uint8List?
no setter
caller int?
final
customDetails Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
isResponseClosed bool Function()
final
packedPayloadBytes Uint8List?
no setter
payload LazyMessagePayload
final
pptCipher String?
final
pptKeyId String?
final
pptScheme String?
final
pptSerializer String?
final
procedure String?
final
progress bool
final
receiveProgress bool
final
registrationId int
final
requestId int
final
respondWith InvocationPayloadResponder
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPayload() InvocationPayload
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited