LocalTransport class

Inheritance

Constructors

LocalTransport({String authenticationPassword = "password", SigningKey? authenticationKey})

Properties

authenticationKey ↔ SigningKey
getter/setter pair
authenticationPassword String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isOpen bool
no setteroverride
isReady bool
no setteroverride
onConnectionLost Completer
no setteroverride
onDisconnect Completer
no setteroverride
onReady Future<void>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sentMessages Stream<AbstractMessage>
Allow tests to listen to what was sent via the transport
no setter

Methods

close({dynamic error}) Future<void>?
override
complete(Completer? onDisconnectCompleter, dynamic error) → void
for internal use only is called to complete the private underlying onDisconnect with a void or an error
inherited
injectIncomingMessage(AbstractMessage message) → void
Allow tests to inject messages into the receive stream
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open({Duration? pingInterval}) Future<void>?
override
receive() Stream<AbstractMessage?>
override
send(AbstractMessage message) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited