MessageTypes class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- codeAbort → int
-
final
- codeAuthenticate → int
-
final
- codeCall → int
-
final
- codeCancel → int
-
final
- codeChallenge → int
-
final
- codeError → int
-
final
- codeEvent → int
-
final
- codeGoodbye → int
-
final
- codeHeartbeat → int
-
final
- codeHello → int
-
final
- codeInterrupt → int
-
final
- codeInvocation → int
-
final
- codePublish → int
-
final
- codePublished → int
-
final
- codeRegister → int
-
final
- codeRegistered → int
-
final
- codeResult → int
-
final
- codeSubscribe → int
-
final
- codeSubscribed → int
-
final
- codeUnregister → int
-
final
- codeUnregistered → int
-
final
- codeUnsubscribe → int
-
final
- codeUnsubscribed → int
-
final
- codeWelcome → int
-
final
- codeYield → int
-
final