- Implemented types
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsFileSegments → bool
-
no setterinherited
- supportsNativeE2eeFileSegments → bool
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openFileSegmentSource(
String path, int expectedLength) → TransportFileSource -
inherited
-
sendFileSegment(
AbstractMessage message, {required TransportFileSource source, required int offset, required int length}) → void -
inherited
-
sendNativeE2eeFileSegment(
AbstractMessage message, {required TransportFileSource source, required int offset, required int length, required NativeE2eeFileSegmentContext e2ee}) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited