NativeWebSocketTransport class

Inheritance
Implemented types

Constructors

NativeWebSocketTransport(String url, AbstractSerializer serializer, String serializerType, [Map<String, dynamic>? headers, bool allowInsecureCertificates = false, String? libraryPath, int? fragmentSize])
NativeWebSocketTransport.withCborSerializer(String url, [Map<String, dynamic>? headers, bool allowInsecureCertificates = false, String? libraryPath, int? fragmentSize])
factory
NativeWebSocketTransport.withJsonSerializer(String url, [Map<String, dynamic>? headers, bool allowInsecureCertificates = false, String? libraryPath, int? fragmentSize])
factory
NativeWebSocketTransport.withMsgpackSerializer(String url, [Map<String, dynamic>? headers, bool allowInsecureCertificates = false, String? libraryPath, int? fragmentSize])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isOpen bool
no setteroverride
isReady bool
no setteroverride
onConnectionLost Completer?
no setteroverride
onDisconnect Completer?
no setteroverride
onReady Future<void>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportsFileSegments bool
no setteroverride
supportsNativeE2eeFileSegments bool
no setteroverride

Methods

close({dynamic error}) Future<void>?
override
complete(Completer? onDisconnectCompleter, dynamic error) → void
for internal use only is called to complete the private underlying onDisconnect with a void or an error
inherited
drain() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open({Duration? pingInterval}) Future<void>?
override
openFileSegmentSource(String path, int expectedLength) TransportFileSource
override
receive() Stream<AbstractMessage?>?
override
send(AbstractMessage message) → void
override
sendFileSegment(AbstractMessage message, {required TransportFileSource source, required int offset, required int length}) → void
override
sendNativeE2eeFileSegment(AbstractMessage message, {required TransportFileSource source, required int offset, required int length, required NativeE2eeFileSegmentContext e2ee}) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited