NegotiatedSessionE2ee class
Constructors
-
NegotiatedSessionE2ee(Map<
String, dynamic> raw)
Properties
- acceptedKeyId → String?
-
no setter
- cipher → String?
-
no setter
- clientPublicKey → String?
-
no setter
- established → bool?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- inboundKeyId → String?
-
no setter
- isRequired → bool?
-
no setter
- kex → String?
-
no setter
- outboundKeyId → String?
-
no setter
- peerKeyId → String?
-
no setter
- peerPublicKey → String?
-
no setter
-
raw
→ Map<
String, dynamic> -
final
- receiveKeyId → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheme → String?
-
no setter
- sendKeyId → String?
-
no setter
- serializer → String?
-
no setter
- serverPublicKey → String?
-
no setter
- version → int?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
verifyRequiredProfile(
{required WampE2eeProvider? provider}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String key) → Object?