PPTPayload class
Constructors
-
PPTPayload({List? arguments, Map<
String, dynamic> ? argumentsKeywords})
Properties
- arguments ↔ List?
-
getter/setter pair
-
argumentsKeywords
↔ Map<
String, dynamic> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
packPPTPayload(
List? arguments, Map< String, dynamic> ? argumentsKeywords, PPTOptions options) → List - Packs PPT Payload and returns 1-item array for WAMP message arguments
-
packSerializedPayload(
String? serializerName, {Uint8List? argumentsBytes, Uint8List? argumentsKeywordsBytes, List? arguments, Map< String, dynamic> ? argumentsKeywords}) → Uint8List? -
unpackPPTPayload(
List? arguments, PPTOptions details) → PPTPayload