RegisterOptions class

Mixed-in types

Constructors

RegisterOptions({bool? discloseCaller, String? match, String? invoke, bool? forwardTimeout, RetryDeduplication? autoDeduplication, Map<String, dynamic>? custom})

Properties

autoDeduplication RetryDeduplication?
getter/setter pair
custom Map<String, dynamic>
Arbitrary implementation-specific fields that should be forwarded over the wire when serializing WAMP options/details.
finalinherited
discloseCaller bool?
getter/setter pair
forwardTimeout bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
invoke String?
getter/setter pair
match String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeCustomField(String key) → void
Removes a previously assigned custom field.
inherited
setCustomField(String key, dynamic value) → void
Assigns value to the custom field key. Existing values are replaced.
inherited
setLazyCustomFieldsLoader(Map<String, dynamic> loader()) → void
inherited
toString() String
A string representation of this object.
inherited
verify() bool

Operators

operator ==(Object other) bool
The equality operator.
inherited