Registered class
- Inheritance
-
- Object
- AbstractMessage
- Registered
Constructors
- Registered(int registerRequestId, int registrationId)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasLazyPayloadInvocationHandler → bool
-
no setter
- hasMaterializedInvocationConsumers → bool
-
no setter
- hasPayloadInvocationHandler → bool
-
no setter
- id ↔ int
-
getter/setter pairinherited
-
invocationStream
↔ Stream<
Invocation> ? -
getter/setter pair
- procedure ↔ String?
-
getter/setter pair
- registerRequestId ↔ int
-
getter/setter pair
- registrationId ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addInvocation(
Invocation invocation) → void -
addInvocationPayload(
InvocationPayload invocation) → void -
addLazyInvocationPayload(
LazyInvocationPayload invocation) → void -
closeInvocationStream(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onInvoke(
FutureOr< void> onInvoke(Invocation invocation)) → void - sets the invocation handler, if an error is thrown within the handler this method will result an error message to the transport or router respectively
-
onInvokePayload(
FutureOr< void> onInvoke(InvocationPayload invocation)) → void -
onLazyInvokePayload(
FutureOr< void> onInvoke(LazyInvocationPayload invocation)) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited