RetryDeduplication class
Bounded router-side handling for application retry transaction hashes.
Constructors
- RetryDeduplication.debounce(Duration debounce, {int capacity = defaultCapacity, Duration expiry = defaultExpiry})
-
Dispatches only the latest matching call after
debounceis quiet.factory - RetryDeduplication.fromWire({required Object autoDeduplication, Object? capacity, Object? expiryMilliseconds})
-
Decodes the Java-compatible value and Connectanum bound fields.
factory
- RetryDeduplication.throttle({int capacity = defaultCapacity, Duration expiry = defaultExpiry})
-
Rejects a duplicate hash while the first invocation is active.
factory
Properties
- capacity → int
-
final
- debounce → Duration?
-
final
- expiry → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDebounce → bool
-
no setter
- isThrottle → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toWireFields(
) → Map< String, int>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- capacityWireField → const String
- defaultCapacity → const int
- defaultExpiry → const Duration
- expiryWireField → const String
- maximumCapacity → const int
- maximumDebounce → const Duration
- maximumExpiry → const Duration
- wireField → const String