call method
This calls a procedure with the given arguments and/or argumentsKeywords
with the given options. The WAMP router will either respond with one or
more results or the caller may cancel the call by calling cancelCompleter.complete().
Implementation
Stream<Result> call(
String procedure, {
List<dynamic>? arguments,
Map<String, dynamic>? argumentsKeywords,
CallOptions? options,
Completer<String>? cancelCompleter,
}) {
return callLazyPayload(
procedure,
payload: LazyMessagePayload.materialized(
arguments: arguments,
argumentsKeywords: argumentsKeywords,
),
options: options,
cancelCompleter: cancelCompleter,
);
}