SessionE2eeProviderContext class

Constructors

SessionE2eeProviderContext({required int? sessionId, required String? realm, required String? authId, required String? authRole, required String? authMethod, required String? authProvider, required Map<String, dynamic>? authExtra, required NegotiatedSessionE2ee? negotiatedE2ee, required WampE2eeProvider? configuredProvider})
const

Properties

authExtra Map<String, dynamic>?
final
authId String?
final
authMethod String?
final
authProvider String?
final
authRole String?
final
configuredProvider WampE2eeProvider?
final
hashCode int
The hash code for this object.
no setterinherited
negotiatedE2ee NegotiatedSessionE2ee?
final
realm String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited