SocketTransport constructor
SocketTransport(
- String host,
- int port,
- AbstractSerializer serializer,
- String serializerType, {
- dynamic ssl = false,
- dynamic allowInsecureCertificates = false,
- Object? tlsSecurityContext,
- dynamic messageLengthExponent = SocketHelper.maxMessageLengthExponent,
This creates a socket transport instance. The messageLengthExponent configures
the max message length that will be excepted to be send and received. It is negotiated
with the router and may lead into a lower value that messageLengthExponent if
the router only supports shorter messages. The message length is calculated by
2^messageLengthExponent
Implementation
SocketTransport(
String host,
int port,
AbstractSerializer serializer,
String serializerType, {
ssl = false,
allowInsecureCertificates = false,
Object? tlsSecurityContext,
messageLengthExponent = SocketHelper.maxMessageLengthExponent,
});