WampE2eeDecryptionException class

Inheritance

Constructors

WampE2eeDecryptionException(String operation, {required PPTOptions options, Object? cause})

Properties

cause Object?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
operation String
finalinherited
options PPTOptions
finalinherited
reason String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited