WampE2eeKeySelectionRule class

Constructors

WampE2eeKeySelectionRule({required String keyId, List<WampE2eeDirection>? directions, List<WampE2eeMessageType>? messageTypes, List<String>? realms, List<String>? uris, List<String>? uriPrefixes, List<String>? localAuthIds, List<String>? localAuthRoles, List<String>? localAuthProviders, List<String>? peerAuthIds, List<String>? peerAuthRoles, List<String>? peerAuthProviders, int? minPeerTrustLevel, int? maxPeerTrustLevel})
const

Properties

directions List<WampE2eeDirection>?
final
hashCode int
The hash code for this object.
no setterinherited
keyId String
final
localAuthIds List<String>?
final
localAuthProviders List<String>?
final
localAuthRoles List<String>?
final
maxPeerTrustLevel int?
final
messageTypes List<WampE2eeMessageType>?
final
minPeerTrustLevel int?
final
peerAuthIds List<String>?
final
peerAuthProviders List<String>?
final
peerAuthRoles List<String>?
final
realms List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uriPrefixes List<String>?
final
uris List<String>?
final

Methods

matches(WampE2eeRuntimeContext runtimeContext) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited