WampFileReceiver class
Bounded receiver for the WampFileSession.setFile wire contract.
Properties
- activeTransfers → int
-
no setter
- bufferedBytes → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- idleTimeout → Duration
-
final
- maxBufferedBytes → int
-
final
- maxChunkSize → int
-
final
- maxConcurrentTransfers → int
-
final
- maxFileSize → int
-
final
- registration ↔ Registered
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
register(
Session session, String procedure, WampFileSinkFactory sinkFactory, {RegisterOptions? options, int maxConcurrentTransfers = 8, int maxFileSize = 16 * 1024 * 1024 * 1024, int maxChunkSize = defaultWampFileChunkSize, int maxBufferedBytes = 8 * 1024 * 1024, Duration idleTimeout = const Duration(seconds: 30)}) → Future< WampFileReceiver>
Constants
- capacityExceededError → const String
- checksumMismatchError → const String
- invalidChunkError → const String
- invalidMetadataError → const String
- sinkFailedError → const String
- timeoutError → const String