WampMetaStateSnapshot class final
An immutable snapshot of visible WAMP Meta API state.
Constructors
- WampMetaStateSnapshot.empty()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
registrations
→ Map<
int, WampRegistrationMeta> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sessions
→ Map<
int, WampSessionMeta> -
final
-
subscriptions
→ Map<
int, WampSubscriptionMeta> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited