WampSubscriptionMeta class final
Standard subscription details plus the current subscriber session IDs.
Constructors
Properties
Methods
-
copyWith(
{required Iterable< int> subscribers}) → WampSubscriptionMeta -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited