FlatBufferByteVectorReference class
Reuse a byte vector already constructed in this builder's storage. This reference never adopts external pointers or another allocation. Consume it during the same build, before resetting the builder.
Constructors
- FlatBufferByteVectorReference(Builder builder, int offset)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited