Serializer class
This is a serializer for JSON messages. It is used to initialize an AbstractTransport object.
- Inheritance
-
- Object
- AbstractSerializer
- Serializer
Constructors
- Serializer({CanonicalBase64ByteDecoder? canonicalBase64ByteDecoder, CanonicalBase64ByteEncoder? canonicalBase64ByteEncoder})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deserialize(
Uint8List? jsonMessage) → AbstractMessage? -
Converts a uint8 JSON message into a WAMP message object
override
-
deserializeFromString(
String jsonMessage) → AbstractMessage? - Converts a string JSON message into a WAMP message object.
-
deserializePPT(
Uint8List binPayload) → PPTPayload? -
Converts a uint8 JSON message into a PPT Payload Object
override
-
installCanonicalBase64ByteDecoder(
CanonicalBase64ByteDecoder decoder) → void - Installs a transport-provided accelerator without replacing an explicit decoder supplied by the application.
-
installCanonicalBase64ByteEncoder(
CanonicalBase64ByteEncoder encoder) → void - Installs a transport-provided accelerator without replacing an explicit encoder supplied by the application.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
AbstractMessage message) → String -
Converts a WAMP message object into a uint8 json message
override
-
serializeFragments(
AbstractMessage message) → List< Uint8List> ? -
Returns encoded message fragments when the serializer can preserve an
already-encoded payload without assembling one contiguous frame.
override
-
serializePPT(
PPTPayload pptPayload) → Uint8List -
Converts a PPT Payload Object into a uint8 array
override
-
serializePPTFragments(
{Uint8List? argumentsBytes, Uint8List? argumentsKeywordsBytes, List? arguments, Map< String, dynamic> ? argumentsKeywords}) → Uint8List -
Serializer PPT payload from already-encoded args / kwargs fragments when
the payload serializer matches the surrounding transport serializer.
override
-
serializeToString(
AbstractMessage message) → String - Converts a WAMP message object into a string json message
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited