McpAuthorizationRequest class final
State retained by an MCP client while the resource owner authorizes access.
Properties
-
final
- clientId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pkce → McpPkcePair
-
final
- redirectUri → Uri
-
final
- resource → Uri
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ List<
String> -
final
- state → String
-
final
- uri → Uri
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited