McpAuthorizationServerMetadata class final
Validated OAuth authorization-server metadata for an MCP client.
Constructors
-
McpAuthorizationServerMetadata.fromJson(Map<
String, Object?> json) -
Revalidates an already obtained authorization-server metadata document.
factory
Properties
-
final
-
Whether RFC 9207 authorization-response issuer parameters are advertised.
final
- clientIdMetadataDocumentSupported → bool?
-
final
-
codeChallengeMethodsSupported
→ List<
String> -
final
-
grantTypesSupported
→ List<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- issuer → Uri
-
final
- issuerIdentifier → String
-
The exact validated issuer identifier from the metadata document.
no setter
- jwksUri → Uri?
-
final
-
raw
→ Map<
String, Object?> -
final
- registrationEndpoint → Uri?
-
final
-
responseTypesSupported
→ List<
String> -
final
- revocationEndpoint → Uri?
-
final
-
revocationEndpointAuthMethodsSupported
→ List<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopesSupported
→ List<
String> ? -
final
- tokenEndpoint → Uri
-
final
-
tokenEndpointAuthMethodsSupported
→ List<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Returns the validated JSON metadata document.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited