McpOAuthDynamicClientRegistration class final

Constructors

McpOAuthDynamicClientRegistration.fromJson(Map<String, Object?> json, {Uri? expectedAuthorizationServerIssuer})
Revalidates a versioned public-client registration document.
factory

Properties

additionalParameters Map<String, Object?>
final
applicationType McpOAuthClientApplicationType
final
authorizationServer McpAuthorizationServerMetadata
final
clientAuthentication McpOAuthClientAuthentication
no setter
clientId String
final
clientIdIssuedAt int?
final
clientName String
final
clientUri Uri?
final
grantTypes List<String>
final
hashCode int
The hash code for this object.
no setterinherited
logoUri Uri?
final
redirectUris List<Uri>
final
responseTypes List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>
final

Methods

createAuthorizationRequest({required Uri resource, required Uri redirectUri, Iterable<String>? scopes, McpPkcePair? pkce}) McpAuthorizationRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Returns a versioned JSON-compatible registration document.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited