McpStreamableSubscription class
Active MCP 2026 request-scoped SSE subscription.
Properties
- acknowledgedNotifications → McpSubscriptionFilter
-
no setter
-
closed
→ Future<
McpSubscriptionCloseReason> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → Object
-
final
-
notifications
→ Stream<
McpJsonMap> -
no setter
- requestedNotifications → McpSubscriptionFilter
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited