McpSubscriptionFilter class
Notification filter requested or acknowledged by subscriptions/listen.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- promptsListChanged → bool
-
final
- resourcesListChanged → bool
-
final
-
resourceSubscriptions
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolsListChanged → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → McpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited