SerializedPayload<TTag, TPayload> class
this is a little helper class for payload serialization and type "safety"
Constructors
- SerializedPayload(TTag payloadType, TPayload payload)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- payload → TPayload
-
final
- payloadType → TTag
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited