putInt32 method
Writes a Uint32 to the tail of the buffer after preparing space for it.
Updates the offset pointer. This method is intended for use when writing structs to the buffer.
Implementation
@override
void putInt32(int value) => _write(() => _builder.putInt32(value));